aboutsummaryrefslogtreecommitdiffstats
path: root/host/examples/rx_ascii_art_dft.cpp
diff options
context:
space:
mode:
authorJason Abele <jason@ettus.com>2011-09-16 10:47:54 -0700
committerJosh Blum <josh@joshknows.com>2011-09-21 16:03:46 -0700
commit539c9b5a5560ea5d79c78954ea8e482846a5e966 (patch)
treea577fc45164ff61f539231cf88c5a2560dc62638 /host/examples/rx_ascii_art_dft.cpp
parent42c7aaa480548716d211c3dcdd2ced1d3c79b510 (diff)
downloaduhd-539c9b5a5560ea5d79c78954ea8e482846a5e966.tar.gz
uhd-539c9b5a5560ea5d79c78954ea8e482846a5e966.tar.bz2
uhd-539c9b5a5560ea5d79c78954ea8e482846a5e966.zip
Updates to example apps
Add --ref option to specify mboard clock reference source Add check for lock to mboard clock reference (where applicable) Add check of daughterboard LO lock detect (where applicable)
Diffstat (limited to 'host/examples/rx_ascii_art_dft.cpp')
-rw-r--r--host/examples/rx_ascii_art_dft.cpp39
1 files changed, 37 insertions, 2 deletions
diff --git a/host/examples/rx_ascii_art_dft.cpp b/host/examples/rx_ascii_art_dft.cpp
index fa8c4d4a4..11a0ccc24 100644
--- a/host/examples/rx_ascii_art_dft.cpp
+++ b/host/examples/rx_ascii_art_dft.cpp
@@ -32,7 +32,7 @@ int UHD_SAFE_MAIN(int argc, char *argv[]){
uhd::set_thread_priority_safe();
//variables to be set by po
- std::string args, ant, subdev;
+ std::string args, ant, subdev, ref;
size_t num_bins;
double rate, freq, gain, bw, frame_rate;
float ref_lvl, dyn_rng;
@@ -54,6 +54,7 @@ int UHD_SAFE_MAIN(int argc, char *argv[]){
("frame-rate", po::value<double>(&frame_rate)->default_value(5), "frame rate of the display (fps)")
("ref-lvl", po::value<float>(&ref_lvl)->default_value(0), "reference level for the display (dB)")
("dyn-rng", po::value<float>(&dyn_rng)->default_value(60), "dynamic range for the display (dB)")
+ ("ref", po::value<std::string>(&ref)->default_value("INTERNAL"), "waveform type (INTERNAL, EXTERNAL, MIMO)")
;
po::variables_map vm;
po::store(po::parse_command_line(argc, argv, desc), vm);
@@ -70,7 +71,21 @@ int UHD_SAFE_MAIN(int argc, char *argv[]){
std::cout << boost::format("Creating the usrp device with: %s...") % args << std::endl;
uhd::usrp::multi_usrp::sptr usrp = uhd::usrp::multi_usrp::make(args);
- //always select the subdevice first, the channel mapping affects the other settings
+ //Lock mboard clocks
+ if (ref == "MIMO") {
+ uhd::clock_config_t clock_config;
+ clock_config.ref_source = uhd::clock_config_t::REF_MIMO;
+ clock_config.pps_source = uhd::clock_config_t::PPS_MIMO;
+ usrp->set_clock_config(clock_config, 0);
+ }
+ else if (ref == "EXTERNAL") {
+ usrp->set_clock_config(uhd::clock_config_t::external(), 0);
+ }
+ else if (ref == "INTERNAL") {
+ usrp->set_clock_config(uhd::clock_config_t::internal(), 0);
+ }
+
+ //always select the subdevice first, the channel mapping affects the other settings
if (vm.count("subdev")) usrp->set_rx_subdev_spec(subdev);
std::cout << boost::format("Using Device: %s") % usrp->get_pp_string() << std::endl;
@@ -112,6 +127,26 @@ int UHD_SAFE_MAIN(int argc, char *argv[]){
boost::this_thread::sleep(boost::posix_time::seconds(1)); //allow for some setup time
+ //Check Ref and LO Lock detect
+ std::vector<std::string> sensor_names;
+ sensor_names = usrp->get_rx_sensor_names(0);
+ if (std::find(sensor_names.begin(), sensor_names.end(), "lo_locked") != sensor_names.end()) {
+ uhd::sensor_value_t lo_locked = usrp->get_rx_sensor("lo_locked",0);
+ std::cout << boost::format("Checking RX: %s ...") % lo_locked.to_pp_string() << std::endl;
+ UHD_ASSERT_THROW(lo_locked.to_bool());
+ }
+ sensor_names = usrp->get_mboard_sensor_names(0);
+ if ((ref == "MIMO") and (std::find(sensor_names.begin(), sensor_names.end(), "mimo_locked") != sensor_names.end())) {
+ uhd::sensor_value_t mimo_locked = usrp->get_mboard_sensor("mimo_locked",0);
+ std::cout << boost::format("Checking RX: %s ...") % mimo_locked.to_pp_string() << std::endl;
+ UHD_ASSERT_THROW(mimo_locked.to_bool());
+ }
+ if ((ref == "EXTERNAL") and (std::find(sensor_names.begin(), sensor_names.end(), "ref_locked") != sensor_names.end())) {
+ uhd::sensor_value_t ref_locked = usrp->get_mboard_sensor("ref_locked",0);
+ std::cout << boost::format("Checking RX: %s ...") % ref_locked.to_pp_string() << std::endl;
+ UHD_ASSERT_THROW(ref_locked.to_bool());
+ }
+
//allocate recv buffer and metatdata
uhd::rx_metadata_t md;
std::vector<std::complex<float> > buff(num_bins);